@@ -99,6 +99,8 @@ func getConfig() (saramaConfig *sarama.Config) {
 		} else {
 			saramaConfig.Net.TLS.Config = &tls.Config{InsecureSkipVerify: false}
 		}
+	}
+	if cluster.SecurityProtocol == "SASL_SSL" || cluster.SecurityProtocol == "SASL_PLAINTEXT" {
 		if cluster.SASL.Mechanism == "SCRAM-SHA-512" {
 			saramaConfig.Net.SASL.SCRAMClientGeneratorFunc = func() sarama.SCRAMClient { return &XDGSCRAMClient{HashGeneratorFcn: SHA512} }
 			saramaConfig.Net.SASL.Mechanism = sarama.SASLMechanism(sarama.SASLTypeSCRAMSHA512)
@@ -205,6 +207,7 @@ func onInit() {
 	// Any set flags override the configuration
 	if schemaRegistryURL != "" {
 		currentCluster.SchemaRegistryURL = schemaRegistryURL
+		currentCluster.SchemaRegistryCredentials = nil
 	}
 
 	if brokersFlag != nil {
@@ -245,7 +248,12 @@ func getSchemaCache() (cache *avro.SchemaCache) {
 	if currentCluster.SchemaRegistryURL == "" {
 		return nil
 	}
-	cache, err := avro.NewSchemaCache(currentCluster.SchemaRegistryURL)
+	var username, password string
+	if creds := currentCluster.SchemaRegistryCredentials; creds != nil {
+		username = creds.Username
+		password = creds.Password
+	}
+	cache, err := avro.NewSchemaCache(currentCluster.SchemaRegistryURL, username, password)
 	if err != nil {
 		errorExit("Unable to get schema cache :%v\n", err)
 	}
